---

slug: /vector-search-supported-clients-and-languages-overview
---

# Supported clients and languages for vector search

| Client/Language | Version |
|---|---|
| MySQL client | All versions |
| Python SDK | 3.9+ |
| Java SDK | 1.8 |
